@@ -276,8 +276,8 @@ gpdf_annots_view_class_init (GPdfAnnotsViewClass *klass)
 		gobject_class, PROP_VIEW,
 		g_param_spec_object (
 			"view",
-			"Parent view",
-			"Parent view",
+			_("Parent view"),
+			_("Parent view"),
 			GPDF_TYPE_VIEW, 
 		        (GParamFlags)(G_PARAM_CONSTRUCT_ONLY | G_PARAM_WRITABLE)));
 
@@ -285,8 +285,8 @@ gpdf_annots_view_class_init (GPdfAnnotsViewClass *klass)
 		gobject_class, PROP_CONTROL,
 		g_param_spec_object (
 			"control",
-			"Parent control",
-			"Parent control",
+			_("Parent control"),
+			_("Parent control"),
 			GPDF_TYPE_CONTROL, 
 		        (GParamFlags)(G_PARAM_CONSTRUCT_ONLY | G_PARAM_WRITABLE)));
 
