@@ -220,8 +220,8 @@ gpdf_bookmarks_view_class_init (GPdfBookmarksViewClass *klass)
 		gobject_class, PROP_VIEW,
 		g_param_spec_object (
 			"view",
-			"Parent view",
-			"Parent view",
+			_("Parent view"),
+			_("Parent view"),
 			GPDF_TYPE_VIEW, 
 		        (GParamFlags)(G_PARAM_CONSTRUCT_ONLY | G_PARAM_WRITABLE)));
 
@@ -229,8 +229,8 @@ gpdf_bookmarks_view_class_init (GPdfBookmarksViewClass *klass)
 		gobject_class, PROP_CONTROL,
 		g_param_spec_object (
 			"control",
-			"Parent control",
-			"Parent control",
+			_("Parent control"),
+			_("Parent control"),
 			GPDF_TYPE_CONTROL, 
 		        (GParamFlags)(G_PARAM_CONSTRUCT_ONLY | G_PARAM_WRITABLE)));
 
@@ -576,7 +576,7 @@ gpdf_bookmarks_view_new (GPdfControl *control, GtkWidget *gpdf_view)
 	  GPDF_BOOKMARKS_VIEW (g_object_new (
 		  GPDF_TYPE_BOOKMARKS_VIEW,
 		  "view", GPDF_VIEW (gpdf_view),
-		  "control", control,
+		  "control", control, 
 		  NULL));
 
 	g_object_ref (G_OBJECT (bookmarks_view->priv->gpdf_view));
@@ -627,15 +627,15 @@ gpdf_bookmarks_view_dispose (GObject *object)
 		g_object_unref (priv->gpdf_view);
 		priv->gpdf_view = NULL; 
 	}
+	if (priv->parent) {
+		g_object_unref (priv->parent);
+		priv->parent = NULL; 
+	}
 	if (priv->popup_menu) {
 		gtk_widget_destroy (priv->popup_menu);
 		priv->popup_menu = NULL;
 		g_free (priv->popup_menu_uiinfo);
 	}
-	if (priv->parent) {
-		g_object_unref (priv->parent);
-		priv->parent = NULL; 
-	}
 
 	G_OBJECT_CLASS (parent_class)->dispose (object);
 }
@@ -735,13 +735,15 @@ gpdf_bookmarks_view_update_popup_actions (GPdfBookmarksView *bookmarks_view)
 		}
 	}
 
-	item = priv->popup_menu_uiinfo[POPUP_MENU_EXPAND_INDEX].widget;
-	if (GTK_IS_WIDGET (item))
-	  gtk_widget_set_sensitive (item, is_expandable && !is_expanded); 
+	if (gpdf_bookmarks_view_have_outline_items (bookmarks_view)) {
+		item = priv->popup_menu_uiinfo[POPUP_MENU_EXPAND_INDEX].widget;
+		if (GTK_IS_WIDGET (item))
+			gtk_widget_set_sensitive (item, is_expandable && !is_expanded); 
 	
-	item = priv->popup_menu_uiinfo[POPUP_MENU_COLLAPSE_INDEX].widget;
-	if (GTK_IS_WIDGET (item))
-	  gtk_widget_set_sensitive (item, is_expandable && is_expanded);	
+		item = priv->popup_menu_uiinfo[POPUP_MENU_COLLAPSE_INDEX].widget;
+		if (GTK_IS_WIDGET (item))
+			gtk_widget_set_sensitive (item, is_expandable && is_expanded);	
+	}
 }
 
 static gboolean
@@ -910,12 +912,13 @@ gpdf_bookmarks_view_flat_recurse_outlines (GPdfBookmarksView *bookmarks_view)
 			default:
 				pagestr = g_strdup ("Unknown"); 
 				g_warning ("Unkown link action type");
+				/* FIXME: free me later */
 			}
 
-			ratio = ((double)page/(double)priv->pdf_doc->getNumPages ()) /2.0; 
-			status = g_strdup_printf ("%d/%d: %2d %%",
+			ratio = ((double)page/(double)priv->pdf_doc->getNumPages ()); 
+			status = g_strdup_printf ("Processing bookmarks on page %d/%d: %2d %%",
 						  page, 
-						  priv->pdf_doc->getNumPages () *2, 
+						  priv->pdf_doc->getNumPages (), 
 						  (int)(ratio*100.0));
 			gpdf_control_private_set_status (priv->parent, status);
 			gpdf_control_private_set_fraction (priv->parent, ratio); 
@@ -928,22 +931,8 @@ gpdf_bookmarks_view_flat_recurse_outlines (GPdfBookmarksView *bookmarks_view)
 					    GPDF_BKVIEW_COLUMN4, (gpointer)anItem,
 					    GPDF_BKVIEW_COLUMN5, page, 
 					    -1);
-			g_free (pagestr);
 		}
-		/*
-		 * Title bookmark (root bookmark on page 1) have null link_action:
-		 * just goto page 1
-		 * These appears on some pdf and no bookmarks at all were displayed
-		 * before because of early recursion failure at build time in
-		 * bookmarks view.
-		 * The following else handle this case. An expecption is made in
-		 * gpdf-view to jump to page 1.
-		 */
 		else if (title) {
-			/* Ensure we are at root */
- 			g_assert (priv->generation_state == priv->generation_head && 
-				  priv->generation_state->level == 0);
-				  
 			gtk_tree_store_append (GTK_TREE_STORE (priv->model),
 					       &child_iter,
 					       priv->generation_state->parent_iter);
@@ -1145,7 +1134,8 @@ gpdf_bookmarks_view_populate_idle (GPdfBookmarksView *bookmarks_view)
 		if (GDK_IS_WINDOW (parent_window))
 			gdk_window_set_cursor (parent_window, NULL); 
 		gdk_flush();
-		g_signal_handler_disconnect (G_OBJECT (priv->parent), priv->idle_dcon_id); 
+		if (priv->idle_dcon_id)
+		  g_signal_handler_disconnect (G_OBJECT (priv->parent), priv->idle_dcon_id); 
 		gpdf_control_private_clear_stack (priv->parent);
 		gpdf_control_private_set_fraction (priv->parent, 0.0); 
 		gpdf_bookmarks_view_emit_ready (bookmarks_view);
@@ -1299,12 +1289,12 @@ gpdf_bookmarks_view_get_tools_menu (GPdfBookmarksView *bookmarks_view)
 		item = priv->popup_menu_uiinfo[POPUP_MENU_EXPAND_INDEX].widget;
 		gtk_widget_set_sensitive (item, FALSE);
 
-		item = priv->popup_menu_uiinfo[POPUP_MENU_EXPAND_ALL_INDEX].widget;
-		gtk_widget_set_sensitive (item, TRUE); 
-
 		item = priv->popup_menu_uiinfo[POPUP_MENU_COLLAPSE_INDEX].widget;
 		gtk_widget_set_sensitive (item, FALSE); 
 
+		item = priv->popup_menu_uiinfo[POPUP_MENU_EXPAND_ALL_INDEX].widget;
+		gtk_widget_set_sensitive (item, TRUE); 
+
 		item = priv->popup_menu_uiinfo[POPUP_MENU_COLLAPSE_ALL_INDEX].widget;
 		gtk_widget_set_sensitive (item, TRUE); 
 	}
