@@ -17,7 +17,6 @@
 #include <time.h>
 #include <unistd.h>
 #include "gpdf-control.h"
-#include "gpdf-control-private.h"
 #include "gpdf-stock-icons.h"
 #include "gpdf-view.h"
 #include "gpdf-bookmarks-view.h"
@@ -423,31 +422,17 @@ gpdf_control_private_get_annots_view (GPdfControl * control)
 }
 #endif
 
-void
-destroy_widget_unref_control (GtkWidget *widget, gint arg1, BonoboControl *control)
-{
-	g_return_if_fail (GTK_IS_WIDGET (widget));
-	g_return_if_fail (BONOBO_IS_CONTROL (control));
-
-	gtk_widget_destroy (widget);
-	bonobo_object_unref (BONOBO_OBJECT (control));
-}
-
 /* Create a HIG compliant dialog, display it and
    wait until response */
 void
 gpdf_control_private_error_dialog (GPdfControl * control,
 				   const gchar *header_text,
 				   const gchar *body_text,
-				   gboolean modal,
-				   gboolean ref_parent)
+				   gboolean modal)
 {
 	GtkWidget *dlg, *but;
 
 	g_return_if_fail (GPDF_IS_NON_NULL_CONTROL (control));
-	if (ref_parent)
-		bonobo_object_ref (BONOBO_OBJECT (control));
-
 	dlg = gpdf_hig_dialog_new (GTK_STOCK_DIALOG_ERROR,
 				   header_text,
 				   body_text,
@@ -461,14 +446,10 @@ gpdf_control_private_error_dialog (GPdfControl * control,
 	if (modal) {
 		gtk_dialog_run (GTK_DIALOG (dlg));
 		gtk_widget_destroy (dlg);
-		if (ref_parent)
-			bonobo_object_unref (BONOBO_OBJECT (control));
 	} else {
 		g_signal_connect (G_OBJECT (dlg), "response",
-				  (ref_parent
-				   ? G_CALLBACK (destroy_widget_unref_control)
-				   : G_CALLBACK (gtk_widget_destroy)),
-				  control);
+				  G_CALLBACK (gtk_widget_destroy),
+				  NULL);
 		gtk_widget_show (dlg);
 	}		
 }
@@ -554,7 +535,6 @@ gpdf_control_private_display_help (BonoboControl *control,
 		gpdf_control_private_error_dialog (gpdf_control,
 						   _("Documentation Error"),
 						   msg,
-						   FALSE,
 						   FALSE);
 	}
 }
@@ -767,7 +747,7 @@ idle_print_handler (GPdfPrintJob *pj)
 
 		pj->pdf_doc->displayPage (pj->ps_output_dev,
 					  pj->page_next,
-					  72, 0, gFalse);
+					  72.0, 72.0, 0, gTrue, gFalse);
 		pj->page_next++;
 		return TRUE;
 	} else {
@@ -893,7 +873,6 @@ gpdf_control_no_postscript_printer_alert (GPdfControl *control,
 		control,
 		_("Printing is not supported on this printer."),
 		secondary,
-		FALSE,
 		FALSE);
 
 	g_free (secondary);
@@ -1947,7 +1926,7 @@ persist_file_loading_failed_cb (GPdfPersistFile *persist_file,
 		_("Loading of %s failed."),
 		gpdf_persist_file_get_current_uri (persist_file));
 
-	gpdf_control_private_error_dialog (control, primary, message, FALSE, TRUE);
+	gpdf_control_private_error_dialog (control, primary, message, FALSE);
 
 	g_free (primary);
 
@@ -2325,12 +2304,6 @@ gpdf_control_setup_view_widgets (GPdfControl *control)
 	control->priv->gpdf_view = gpdf_view;
 	gtk_container_add (GTK_CONTAINER (sw), gpdf_view);
 
-	/* Workaround for 132489 */
-	gtk_scrolled_window_get_hadjustment (GTK_SCROLLED_WINDOW (sw))
-		->step_increment = 10;
-	gtk_scrolled_window_get_vadjustment (GTK_SCROLLED_WINDOW (sw))
-		->step_increment = 10;
-	
 	g_signal_connect (G_OBJECT (gpdf_view), "page_changed",
 			  G_CALLBACK (gc_page_changed_enable_page_buttons),
 			  control);
