@@ -94,7 +94,7 @@ struct _GPdfThumbnailsViewPrivate {
 	
 	gint current_page;
 	double zoom;
-	gint current_gen_thumb;
+	guint current_gen_thumb;
 	guint idle_id; 
 	gulong idle_dcon_id; 
 
@@ -212,8 +212,8 @@ gpdf_thumbnails_view_class_init (GPdfThumbnailsViewClass *klass)
 		gobject_class, PROP_VIEW,
 		g_param_spec_object (
 			"view",
-			"Parent view",
-			"Parent view",
+			_("Parent view"),
+			_("Parent view"),
 			GPDF_TYPE_VIEW, 
 		        (GParamFlags)(G_PARAM_CONSTRUCT_ONLY | G_PARAM_WRITABLE)));
 
@@ -221,8 +221,8 @@ gpdf_thumbnails_view_class_init (GPdfThumbnailsViewClass *klass)
 		gobject_class, PROP_CONTROL,
 		g_param_spec_object (
 			"control",
-			"Parent control",
-			"Parent control",
+			_("Parent control"),
+			_("Parent control"),
 			GPDF_TYPE_CONTROL, 
 		        (GParamFlags)(G_PARAM_CONSTRUCT_ONLY | G_PARAM_WRITABLE)));
 
@@ -628,8 +628,8 @@ gpdf_thumbnails_view_new (GPdfControl *parent, GtkWidget *gpdf_view)
 	thumbnails_view =
 	  GPDF_THUMBNAILS_VIEW (g_object_new (
 		  GPDF_TYPE_THUMBNAILS_VIEW, 
-		  "view", GPDF_VIEW (gpdf_view),
-		  "control", GPDF_CONTROL (parent), 
+		  "view", (gpointer)gpdf_view,
+		  "control", (gpointer)parent, 
 		  NULL));
 
 	g_object_ref (G_OBJECT (thumbnails_view->priv->gpdf_view)); 
@@ -1269,7 +1269,7 @@ gpdf_thumbnails_view_populate_idle (GPdfThumbnailsView *thumbnails_view)
 	GPdfThumbnailsViewPrivate *priv;
 	Page *the_page;
 	Object the_thumb;
-	Thumb *thumb;
+	Thumb *thumb = NULL;
 	gboolean have_ethumbs = FALSE;
 	gchar *status = NULL;
 	double ratio = 0.0; 
@@ -1278,10 +1278,10 @@ gpdf_thumbnails_view_populate_idle (GPdfThumbnailsView *thumbnails_view)
 			      TRUE);
 	
 	priv = thumbnails_view->priv;
-	ratio = 0.5 + ((double)priv->current_gen_thumb/(double)priv->num_pages) /2.0; 
-	status = g_strdup_printf ("%d/%d: %3d %%",
-				  priv->num_pages + priv->current_gen_thumb,
-				  priv->num_pages *2, 
+	ratio = ((double)priv->current_gen_thumb/(double)priv->num_pages); 
+	status = g_strdup_printf ("Processing thumbnail #%d/%d: %3d %%",
+				  priv->current_gen_thumb,
+				  priv->num_pages, 
 				  (int)(ratio*100.0));
 	gpdf_control_private_set_status (priv->parent, status);
 	gpdf_control_private_set_fraction (priv->parent, ratio); 
