@@ -78,6 +78,9 @@ struct _GPdfViewPrivate {
 	gboolean (*annots_cb)(Annot *annot, gpointer data);
 	GPdfAnnotsView *annots_view;
 #endif
+
+	guint status_to_id;
+	
 	GPdfControl *parent;
 };
 
@@ -340,14 +343,18 @@ gpdf_view_link_action_uri (GPdfView *gpdf_view, LinkURI *link_uri)
 	g_return_if_fail (dynamic_cast <LinkURI *> (link_uri) != NULL);
 
 	uri = g_strdup (link_uri->getURI ()->getCString ()); 
+	g_message ("gpdf_view_link_action_uri: uri = '%s'", uri); 
 	uris = g_list_append (uris, uri);
 
 	vfsuri = gnome_vfs_uri_new ((const gchar *)uris->data); 
 	mime = gnome_vfs_get_mime_type_common (vfsuri);
-	gnome_vfs_uri_unref (vfsuri); 
 
-	if (!mime)
-	  mime = "text/html";
+	g_message ("gpdf_view_link_action_uri: mime = '%s'", mime); 
+
+	if (!mime) {
+		mime = "text/html";
+		g_message ("gpdf_view_link_action_uri: using default mime = '%s'", mime); 
+	}
 
 	action = gnome_vfs_mime_get_default_action (mime); 
 	if (gnome_vfs_mime_action_launch (action, uris) != GNOME_VFS_OK)
@@ -371,8 +378,7 @@ gpdf_view_link_action_uri (GPdfView *gpdf_view, LinkURI *link_uri)
 					gpdf_control_private_error_dialog (gpdf_view->priv->parent, 
 									   _("Application Launch Failure!"),
 									   msg,
-									   TRUE,
-									   FALSE);
+									   TRUE);
 					g_free (msg);
 				}
 			}
@@ -390,8 +396,9 @@ gpdf_view_link_action_uri (GPdfView *gpdf_view, LinkURI *link_uri)
 
 		gnome_vfs_mime_application_free (app); 
 	}
-	g_free (uri); 
 	g_list_free (uris); 
+	gnome_vfs_uri_unref (vfsuri); 
+	delete uri; 
 }
 
 static void
@@ -427,6 +434,187 @@ gpdf_view_link_clicked_cb (GPdfLinksCanvasLayer *links_layer,
 	}
 }
 
+static gboolean
+gpdf_view_reset_link_status_cb (gpointer user_data)
+{
+    GPdfView *gpdf_view;
+    GPdfViewPrivate *priv;
+    
+    g_return_val_if_fail (GPDF_IS_VIEW (user_data), FALSE);
+
+    gpdf_view = GPDF_VIEW (user_data);
+    priv = gpdf_view->priv;
+
+    gpdf_control_private_clear_stack (priv->parent);
+    priv->status_to_id = 0;
+    
+    return FALSE;
+}
+
+static void
+gpdf_view_link_entered_cb (GPdfLinksCanvasLayer *links_layer,
+			   Link                 *link,
+			   gpointer              user_data)
+{
+	GPdfView *gpdf_view;
+	GPdfViewPrivate *priv;
+
+	g_return_if_fail (GPDF_IS_VIEW (user_data));
+	g_return_if_fail (dynamic_cast <Link *> (link) != NULL);
+
+	gpdf_view = GPDF_VIEW (user_data);
+	priv = gpdf_view->priv;
+
+	if (link) {
+	    LinkAction *action = link->getAction ();
+	    gchar *text = NULL;
+	    
+	    switch (action->getKind ()) {
+	      case actionGoTo:
+	      {
+		  LinkGoTo *link_goto;
+		  LinkDest *link_dest;
+		  GString *named_dest;
+		  Ref page_ref;
+		  guint page = 0;
+		  
+		  link_goto = dynamic_cast <LinkGoTo *> (action);
+		  link_dest = link_goto->getDest ();
+		  named_dest = link_goto->getNamedDest ();
+		  if (link_dest != NULL) {
+		      link_dest = link_dest->copy ();
+		  } else if (named_dest != NULL) {
+		      named_dest = named_dest->copy ();
+		      link_dest = priv->pdf_doc->findDest (named_dest);
+		      delete named_dest;
+		  }
+		  if (link_dest != NULL) {
+		      if (link_dest->isPageRef ()) {
+			  page_ref = link_dest->getPageRef ();
+			  page = priv->pdf_doc->findPage (page_ref.num, page_ref.gen);
+		      } else {
+			  page = link_dest->getPageNum ();
+		      }
+		      
+		      delete link_dest;
+		  }
+		  text = g_strdup_printf (_("Go to page #%d"), page);
+		  break;
+	      }
+	      case actionGoToR:
+	      {
+		  LinkGoToR *link_gotor;
+		  LinkDest *link_dest;
+		  GString *named_dest;
+		  Ref page_ref;
+		  guint page = 0;
+		  GString *filename;
+		  
+		  link_gotor = dynamic_cast <LinkGoToR *> (action);
+		  link_dest = link_gotor->getDest ();
+		  named_dest = link_gotor->getNamedDest ();
+		  filename = link_gotor->getNamedDest ();
+		  if (link_dest != NULL) {
+		      link_dest = link_dest->copy ();
+		  } else if (named_dest != NULL) {
+		      named_dest = named_dest->copy ();
+		      link_dest = priv->pdf_doc->findDest (named_dest);
+		      delete named_dest;
+		  }
+		  if (link_dest != NULL) {
+		      if (link_dest->isPageRef ()) {
+			  page_ref = link_dest->getPageRef ();
+			  page = priv->pdf_doc->findPage (page_ref.num, page_ref.gen);
+		      } else {
+			  page = link_dest->getPageNum ();
+		      }
+		      
+		      delete link_dest;
+		  }
+		  text = g_strdup_printf (_("Go to file %s:#%d"), filename->getCString (), page); 
+		  break;
+	      }		
+	      case actionLaunch:
+	      {
+		  LinkLaunch *link_launch = NULL;
+		  
+		  link_launch = dynamic_cast <LinkLaunch *> (link_launch);
+		  text = g_strdup_printf (_("Launch: %s %s"),
+					  link_launch->getFileName ()->getCString (), 
+					  link_launch->getParams ()->getCString ());
+		  break;
+	      }
+	      case actionURI:
+	      {
+		  LinkURI *link_uri;
+		  
+		  link_uri = dynamic_cast <LinkURI *> (action);
+		  text = g_strdup_printf (_("Browse %s"), link_uri->getURI ()->getCString ());
+		  break; 
+	      }
+	      case actionNamed:
+	      {
+		  LinkNamed *link_named;
+		  
+		  link_named = dynamic_cast <LinkNamed *> (action);
+		  text = g_strdup_printf (_("Action: %s"), link_named->getName ()->getCString ());
+		  break;
+	      }
+	      case actionMovie:
+	      {
+		  LinkMovie *link_movie;
+		  
+		  link_movie = dynamic_cast <LinkMovie *> (action);
+		  text = g_strdup_printf (_("Movie: %s"),
+					  link_movie->getTitle ()->getCString ());
+		  break;
+	      }
+	      case actionUnknown:
+	      default:
+	      {
+		  LinkUnknown *link_unknown;
+		  
+		  link_unknown = dynamic_cast <LinkUnknown *> (action);
+		  g_message ("Click on link: unknown Action");
+		  text = g_strdup_printf (_("Unknown action: %s !"),
+					  link_unknown->getAction ()->getCString ());
+		  break;
+	      }
+	    }
+
+	    if (text) {
+		gpdf_control_private_set_status (priv->parent, text);
+		if (priv->status_to_id)
+		  g_source_remove (priv->status_to_id);
+		priv->status_to_id =
+		  g_timeout_add (3000,
+				 (GSourceFunc)gpdf_view_reset_link_status_cb,
+				 gpdf_view);
+		g_free (text);
+	    }
+	}	
+}
+
+static void
+gpdf_view_link_leaved_cb (GPdfLinksCanvasLayer *links_layer,
+			  Link                 *link,
+			  gpointer              user_data)
+{
+	GPdfView *gpdf_view;
+	GPdfViewPrivate *priv;
+
+	g_return_if_fail (GPDF_IS_VIEW (user_data));
+
+	gpdf_view = GPDF_VIEW (user_data);
+	priv = gpdf_view->priv;
+
+	gpdf_control_private_pop (priv->parent);
+	if (priv->status_to_id) {
+	    g_source_remove (priv->status_to_id);
+	    priv->status_to_id = 0;
+	}
+}
+
 static gboolean
 gpdf_view_render_page (GPdfView *gpdf_view)
 {
@@ -493,18 +681,18 @@ gpdf_view_render_page (GPdfView *gpdf_view)
 #ifdef USE_ANNOTS_VIEW
 	priv->pdf_doc->displayPage (priv->output_dev,
 				    page,
-				    72,
+				    72.0, 72.0, 
 				    0,
-				    gFalse,
+				    gTrue, gFalse,
 				    NULL, NULL, 
 				    priv->annots_cb,
 				    gpdf_view_get_annots_view (gpdf_view));
 #else
 	priv->pdf_doc->displayPage (priv->output_dev,
 				    page,
-				    72,
+				    72.0, 72.0,
 				    0,
-				    gFalse,
+				    gTrue, gFalse,
 				    NULL, NULL, 
 				    NULL, NULL);
 #endif
@@ -537,6 +725,12 @@ gpdf_view_render_page (GPdfView *gpdf_view)
 	g_signal_connect (G_OBJECT (priv->links_layer), "link_clicked",
 			  G_CALLBACK (gpdf_view_link_clicked_cb),
 			  gpdf_view);
+	g_signal_connect (G_OBJECT (priv->links_layer), "link_entered",
+			  G_CALLBACK (gpdf_view_link_entered_cb),
+			  gpdf_view);
+	g_signal_connect (G_OBJECT (priv->links_layer), "link_leaved",
+			  G_CALLBACK (gpdf_view_link_leaved_cb),
+			  gpdf_view);
 
 	gpdf_control_private_reset_cursor (priv->parent);
 	return FALSE;
@@ -925,13 +1119,7 @@ gpdf_view_bookmark_selected (GPdfView   *gpdf_view,
 {
 	g_return_if_fail (GPDF_IS_VIEW (gpdf_view));
 
-	/*
-	 * Title bookmark (root bookmark on page 1) have null link_action:
-	 * just goto page 1
-	 * These appears on some pdf and no bookmarks at all were displayed
-	 * before because of early recursion failure at build time in
-	 * bookmarks view.
-	 */
+	/* Title have null link_action: goto page 1 */
 	if (!link_action)
 		gpdf_view_goto_page (gpdf_view, 1);
 	else
